emacs-orgmode@gnu.org archives
 help / color / mirror / code / Atom feed
* patch for ob-sql.el: improve MySQL header formatting, and add db spec header vars
@ 2013-02-01 15:18 Gary Oberbrunner
  2013-02-01 18:57 ` Gary Oberbrunner
  0 siblings, 1 reply; 3+ messages in thread
From: Gary Oberbrunner @ 2013-02-01 15:18 UTC (permalink / raw)
  To: Orgmode Mailing List


[-- Attachment #1.1: Type: text/plain, Size: 344 bytes --]

Let me know if this would be better as a pull request.  This patch does
three things:

 * add a header-row delimiter to the tables returned from mysql
 * adds new sql-specific header args for the database connection, and
implements them for mysql
 * (minor) adds an edebug spec to org-babel-result-cond to allow edebugging
through it

-- 
Gary

[-- Attachment #1.2: Type: text/html, Size: 450 bytes --]

[-- Attachment #2: org-mode-sql.patch --]
[-- Type: application/octet-stream, Size: 4369 bytes --]

diff --git a/lisp/ob-core.el b/lisp/ob-core.el
index bdf8c54..1a42965 100644
--- a/lisp/ob-core.el
+++ b/lisp/ob-core.el
@@ -2585,7 +2585,8 @@ Emacs shutdown."))
 
 (defmacro org-babel-result-cond (result-params scalar-form &rest table-forms)
   "Call the code to parse raw string results according to RESULT-PARAMS."
-  (declare (indent 1))
+  (declare (indent 1)
+	   (debug (form form &rest form)))
   `(unless (member "none" ,result-params)
      (if (or (member "scalar" ,result-params)
 	     (member "verbatim" ,result-params)
diff --git a/lisp/ob-sql.el b/lisp/ob-sql.el
index 8d2ba24..3ea7112 100644
--- a/lisp/ob-sql.el
+++ b/lisp/ob-sql.el
@@ -52,20 +52,38 @@
 
 (defvar org-babel-default-header-args:sql '())
 
-(defvar org-babel-header-args:sql
-  '((engine   . :any)
-    (out-file . :any)))
+(defconst org-babel-header-args:sql
+  '((engine	. :any)
+    (out-file	. :any)
+    (dbhost	. :any)
+    (dbuser	. :any)
+    (dbpassword	. :any)
+    (dbdatabase	. :any))
+  "SQL-specific header arguments.")
 
 (defun org-babel-expand-body:sql (body params)
   "Expand BODY according to the values of PARAMS."
   (org-babel-sql-expand-vars
    body (mapcar #'cdr (org-babel-get-header params :var))))
 
+(defun dbstring-mysql (host user password database)
+  "Make MySQL cmd line args for database connection.  Pass nil to omit that arg."
+  (combine-and-quote-strings
+   (remq nil
+	 (list (when host     (concat "-h" host))
+	       (when user     (concat "-u" user))
+	       (when password (concat "-p" password))
+	       (when database (concat "-D" database))))))
+
 (defun org-babel-execute:sql (body params)
   "Execute a block of Sql code with Babel.
 This function is called by `org-babel-execute-src-block'."
   (let* ((result-params (cdr (assoc :result-params params)))
          (cmdline (cdr (assoc :cmdline params)))
+         (dbhost (cdr (assoc :dbhost params)))
+         (dbuser (cdr (assoc :dbuser params)))
+         (dbpassword (cdr (assoc :dbpassword params)))
+         (dbdatabase (cdr (assoc :dbdatabase params)))
          (engine (cdr (assoc :engine params)))
          (in-file (org-babel-temp-file "sql-in-"))
          (out-file (or (cdr (assoc :out-file params))
@@ -85,7 +103,8 @@ This function is called by `org-babel-execute-src-block'."
                                      (or cmdline "")
                                      (org-babel-process-file-name in-file)
                                      (org-babel-process-file-name out-file)))
-                    ('mysql (format "mysql %s < %s > %s"
+                    ('mysql (format "mysql %s %s < %s > %s"
+				    (dbstring-mysql dbhost dbuser dbpassword dbdatabase)
                                     (or cmdline "")
 				    (org-babel-process-file-name in-file)
 				    (org-babel-process-file-name out-file)))
@@ -107,19 +126,32 @@ This function is called by `org-babel-execute-src-block'."
       (with-temp-buffer
 	  (progn (insert-file-contents-literally out-file) (buffer-string)))
       (with-temp-buffer
-	;; need to figure out what the delimiter is for the header row
-	(with-temp-buffer
-	  (insert-file-contents out-file)
-	  (goto-char (point-min))
-	  (when (re-search-forward "^\\(-+\\)[^-]" nil t)
-	    (setq header-delim (match-string-no-properties 1)))
-	  (goto-char (point-max))
-	  (forward-char -1)
-	  (while (looking-at "\n")
-	    (delete-char 1)
-	    (goto-char (point-max))
-	    (forward-char -1))
-	  (write-file out-file))
+	(case (intern engine)
+	  ('mysql
+	   ;; add header row delimiter after column-names header in first line
+	   (with-temp-buffer
+	     (insert-file-contents out-file)
+	     (goto-char (point-min))
+	     (forward-line 1)
+	     (insert "-\n")
+	     (setq header-delim "-")
+	     (write-file out-file)
+	     ))
+	  (t
+	   ;; need to figure out what the delimiter is for the header row
+	   (with-temp-buffer
+	     (insert-file-contents out-file)
+	     (goto-char (point-min))
+	     (when (re-search-forward "^\\(-+\\)[^-]" nil t)
+	       (setq header-delim (match-string-no-properties 1)))
+	     (goto-char (point-max))
+	     (forward-char -1)
+	     (while (looking-at "\n")
+	       (delete-char 1)
+	       (goto-char (point-max))
+	       (forward-char -1))
+	     (write-file out-file)))
+	  )
 	(org-table-import out-file '(16))
 	(org-babel-reassemble-table
 	 (mapcar (lambda (x)

^ permalink raw reply related	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2013-02-03 22:54 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2013-02-01 15:18 patch for ob-sql.el: improve MySQL header formatting, and add db spec header vars Gary Oberbrunner
2013-02-01 18:57 ` Gary Oberbrunner
2013-02-03 22:53   ` Eric Schulte

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).